@@ -1,5 +1,5 @@
 use crate::service::version_id::VersionId;
 
-pub(crate) trait IProps {
+pub trait IProps {
     fn get_version(&self) -> VersionId;
 }
\ No newline at end of file
