@@ -1,7 +1,7 @@
 use std::fmt;
 
 #[derive(Debug, Clone)]
-pub(crate) struct HistoryResultError {
+pub struct HistoryResultError {
     message: String
 }
 
